#!/bin/bash
# This script is used to detect whether native versions of
# Fortran, Objective-C, gtk+, wxWidgets, FLTK, etc., are
# installed.  It simply prints the word "yes" if not installed
# or nothing if installed.  The idea is that during IMCROSS
# installation it can be used to autoset configuation variables
# such as NO_GTK, on the grounds that if the native form of a
# library isn't installed, then why would you want the cross
# build of that library installed?

# Collect some info about gcc.
GCCINFO=`mktemp`
gcc -v &>$GCCINFO
echo "" >empty.m 

case "$1" in
  mac )
    # There's lot's of stuff I haven't figure out how
    # to work around when building the Mac tools.
    # At the moment, the known limitations are on the
    # native gcc of the Linux build box:
    #	gcc must be version 4 or later
    #	gcc must support "-x objective-c"
    if gcc -c empty.m &>/dev/null
    then	# Objective-C supported.
      # Yes, Objective-C.  gcc versions?
      if grep -c "gcc version [4-9]" $GCCINFO &>/dev/null
      then
	echo gcc version 4 or later &>/dev/null
      else
	# other gcc version
	echo yes
      fi
    else	# No Objective-C.
      echo yes
    fi
    ;;
  fortran )
    if which g77 &>/dev/null
    then
      echo Fortran 77 &>/dev/null
    elif which gfortran &>/dev/null
    then
      echo Fortran 95 &>/dev/null
    else
      echo yes
    fi
    ;;
  objc )
    # To support Objective C we require not only that
    # gcc have Objective C support.
    if gcc -c empty.m &>/dev/null
    then	# Objective-C is supported.
      echo Supported &>/dev/null
    else	# No Objective-C support.
      echo yes
    fi
    ;;
  gtk )
    if pkg-config gtk+-2.0 --modversion &>/dev/null
    then
      echo gtk+ 2 is installed &>/dev/null
    else
      echo yes
    fi
    ;;
  wxwidgets )
    if which wx-config &>/dev/null
    then
      echo wxWidgets is installed &>/dev/null
    else
      echo yes
    fi
    ;;
  fltk )
    if which fltk-config &>/dev/null
    then
      echo FLTK is installed &>/dev/null
    else
      echo yes
    fi
    ;;
  libxml2 )
    if which xml2-config &>/dev/null
    then
      echo libxml2 is installed &>/dev/null
    else
      echo yes
    fi
    ;;
  allegro )
    # We assume that if you're doing dev work using
    # Allegro, then you must be able to do 
    # "#include <allegro.h>".  According to the 
    # documentation for cpp, the C pre-processor,
    # this implies that allegro.h is in /usr/include
    # or /usr/local/include.  Of course, it may not 
    # be, in which case the following will not detect
    # it and will assume that the dev package for 
    # Allegro is not installed.
    if test -e /usr/include/allegro.h
    then
      echo allegro is installed &>/dev/null
    elif test -e /usr/local/include/allegro.h
    then
      echo allegro is installed &>/dev/null
    else
      echo yes
    fi
    ;;
  * )
    ;;
esac

rm $GCCINFO &>/dev/null
rm empty.m &>/dev/null

